@@ -20,18 +20,13 @@
 #include <vtkPointData.h>
 #include <vtkDataArray.h>
 #include <math.h>
-#  ifdef __WXMAC__
-#    ifdef __DARWIN__
-#      include <OpenGL/gl.h>
-#      include <OpenGL/glu.h>
-#    else
-#      include <gl.h>
-#      include <glu.h>
-#    endif
-#  else
-#     include <GL/gl.h>
-#     include <GL/glu.h>
-#  endif
+#ifdef LXMACOSX
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
+#include <GL/gl.h>
+#include <GL/glu.h>
+#endif
 #endif  
 //LXDEPCHECK - standart libraries
 
