@@ -64,6 +64,7 @@ enum {
   TT_AUTO_JOIN,
   TT_SYSTEM,
   TT_SKETCH_WARP,
+  TT_SKETCH_COLORS,
   TT_TEXT,
   TT_LANG,
 };
@@ -78,6 +79,7 @@ static const thstok thtt_cfg[] = {
   {"language", TT_LANG},
   {"select", TT_SELECT},
   {"setup3d", TT_SETUP3D},
+  {"sketch-colors", TT_SKETCH_COLORS},
   {"sketch-warp", TT_SKETCH_WARP},
   {"source", TT_SOURCE},
   {"system", TT_SYSTEM},
@@ -107,6 +109,8 @@ thconfig::thconfig()
   this->outcs_sumy = 0.0;
   this->outcs_sumn = 0.0;
 
+  this->sketch_colors = 256;
+
   this->tmp3dSMP = 1.0;
   this->tmp3dWALLSMP = 0.1;
   this->tmp3dMAXDIMD = 5.0;
@@ -428,6 +432,22 @@ void thconfig::load()
             this->sketch_warp = sv;
             break;
 
+          case TT_SKETCH_COLORS:
+            if (valuemb.get_size() != 1)
+              ththrow(("invalid argument - use sketch-colors <number>"));
+            {
+              double dum;
+              thparse_double(sv, dum, valuemb.get_buffer()[0]);
+              if (sv != TT_SV_NUMBER)
+                ththrow(("number expected -- %s", valuemb.get_buffer()[0]));
+              int dumi;
+              dumi = int(dum);
+              if ((dumi < 2) || (dumi > 65536))
+                ththrow(("number out of range -- %s", valuemb.get_buffer()[0]));
+              this->sketch_colors = dumi;
+            }
+            break;
+
           case TT_SETUP3D:
             if (valuemb.get_size() > 0) {
               thparse_double(sv, this->tmp3dSMP, valuemb.get_buffer()[0]);
@@ -826,6 +846,17 @@ double thconfig::get_outcs_convergence()
   }
 }
 
+double thconfig::get_cs_convergence(int cs)
+{
+  double x, y, z, lx, ly, lz;
+  if (this->get_outcs_center(x, y, z)) {
+    thcs2cs(thcs_get_data(this->outcs)->params, thcs_get_data(cs)->params, x, y, z, lx, ly, lz);
+    return thcsconverg(thcs_get_data(cs)->params, lx, ly);
+  } else {
+    return 0.0;
+  }
+}
+
 
 bool thconfig::get_outcs_mag_decl(double year, double & decl)
 {
