@@ -49,6 +49,7 @@
 
 using namespace std;
 
+#define IOerr(F) ((string)"Can't open file "+F+"!\n").c_str()
 
 extern map<string,string> RGB, ALL_FONTS, ALL_PATTERNS;
 typedef set<unsigned char> FONTCHARS;
@@ -92,12 +93,17 @@ void MP_text::clear() {
   xx = yy = 1;
   xy = yx = 0;
   size = 0;
+  r = g = b = -1;
   transformed = false;
 }
 
 void MP_text::print_svg(ofstream & F, CGS & gstate) {
-  F << "<text font-family=\"" << font << "\" font-size=\"" << size << 
-       "\" transform=\"matrix(" << xx << " " << xy << " " << -yx << " " << -yy <<
+  F << "<text font-family=\"" << font << "\" font-size=\"" << size << "\" ";
+  if (LAYOUT.colored_text && r>=0 && g>=0 && b>=0) F << 
+    "fill=\"" << rgb2svg(r,g,b) << "\" " <<
+    "stroke=\"black\" stroke-width=\"0.1\" ";
+  else F << "fill=\"black\" stroke=\"none\" ";
+  F << "transform=\"matrix(" << xx << " " << xy << " " << -yx << " " << -yy <<
        " " << x << " " << y << ")\">";
   for (unsigned int i = 0; i < text.size(); i++)
     F << "&#x" << hex << tex2uni(font, int(text[i])) << dec << ";";
@@ -168,17 +174,17 @@ void MP_path::add(int command, string s1, string s2, string s3,
   segments.push_back(seg);
 }
 
-void MP_path::print_svg(ofstream & F, CGS & gstate) {
+void MP_path::print_svg(ofstream & F, CGS & gstate, string unique_prefix) {
   if (fillstroke == MP_clip) {
     CGS::clippathID++;
     gstate.clippathdepth.insert(make_pair(CGS::clippathID,0));
-    F << "<clipPath id=\"clip_" << CGS::clippathID << "\">" << endl << "  ";
+    F << "<clipPath id=\"clip_" << CGS::clippathID << "_" << unique_prefix << "\">" << endl << "  ";
   }
   F << "<path ";
   if (fillstroke != MP_clip) {
     F << "fill=\"" << (fillstroke==MP_fill || fillstroke==MP_fillstroke ? 
            (gstate.pattern == ""? gstate.svg_color() : 
-              "url(#patt_" + gstate.pattern + ")") : "none") <<  
+              "url(#patt_" + gstate.pattern + "_" + unique_prefix + ")") : "none") <<  
          "\" stroke=\"" << (fillstroke==MP_stroke || fillstroke==MP_fillstroke ? 
            gstate.svg_color() : "none") <<  "\" ";
     if (fillstroke==MP_stroke || fillstroke==MP_fillstroke) {
@@ -232,7 +238,7 @@ void MP_path::print_svg(ofstream & F, CGS & gstate) {
   if (closed) F << "Z";
   F << "\" />" << endl;
   if (fillstroke == MP_clip) F << "</clipPath>" << endl << 
-     "<g clip-path=\"url(#clip_" << CGS::clippathID << ")\">" << endl;
+     "<g clip-path=\"url(#clip_" << CGS::clippathID << "_" << unique_prefix << ")\">" << endl;
 }
 
 void MP_data::add(int i) {
@@ -341,13 +347,13 @@ void MP_setting::print_svg (ofstream & F, CGS & gstate) {
   }
 }
 
-void MP_data::print_svg (ofstream & F) {
+void MP_data::print_svg (ofstream & F, string unique_prefix) {
 //  F << "<g id=\"" << ID <<  // plain MP settings follow
 //       "\" stroke-linecap=\"round\" stroke-linejoin=\"round\" stroke-miterlimit=\"10\">" << endl;
   for (unsigned int i=0; i<index.size(); i++) {
     switch (index[i].vector) {
       case I_path:
-        paths[index[i].idx].print_svg(F,gstate);
+        paths[index[i].idx].print_svg(F,gstate,unique_prefix);
         break;
       case I_setting:
         settings[index[i].idx].print_svg(F,gstate);
@@ -392,9 +398,13 @@ void MP_data::print_svg (ofstream & F) {
   assert(gstate.clippathdepth.empty());
 }
 
-void converted_data::print_svg (ofstream & F, long i_patt) {  // i_patt maju byt rozne
+void converted_data::print_svg (ofstream & F, string unique_prefix) { 
+  ostringstream s;
   static long i_patt_def(10000);
-  if (i_patt < 0) i_patt = ++i_patt_def;
+  s << ++i_patt_def;   // i_patt maju byt rozne
+  unique_prefix += "_";
+  unique_prefix += s.str();
+
   F << "<svg width=\"" << 2.54/72*(urx - llx) << 
       "cm\" height=\"" << 2.54/72*(ury - lly) << 
       "cm\" viewBox=\"" << llx << " " << -ury << 
@@ -407,7 +417,7 @@ void converted_data::print_svg (ofstream & F, long i_patt) {  // i_patt maju byt
     for (list<pattern>::iterator J = PATTERNLIST.begin();
                                 J != PATTERNLIST.end(); J++) {
     if (patterns.count(J->name) > 0) {
-        F << "<pattern id=\"patt_" << J->name << 
+        F << "<pattern id=\"patt_" << J->name <<  "_" << unique_prefix <<
             "\" patternUnits=\"userSpaceOnUse\"" << 
             " width=\"" << J->xstep <<   
             "\" height=\"" << J->ystep << 
@@ -417,14 +427,14 @@ void converted_data::print_svg (ofstream & F, long i_patt) {  // i_patt maju byt
             ")\">" << endl;
         F << "<g transform=\"translate(" 
                       << J->llx1-J->llx << " " << J->lly1-J->lly << ")\">" << endl;
-        J->data.MP.print_svg(F);
+        J->data.MP.print_svg(F,unique_prefix);
         F << "</g>" << endl;
         F << "</pattern>" << endl;
       }
     }
   }
   // clip to initial viewBox
-  F << "<clipPath id=\"clip_viewBox_" << i_patt << "\">" << endl;
+  F << "<clipPath id=\"clip_viewBox_" << unique_prefix << "\">" << endl;
   F << "<path d=\"M" << llx << " " << lly << 
       "L" << urx << " " << lly << 
       "L" << urx << " " << ury << 
@@ -433,8 +443,8 @@ void converted_data::print_svg (ofstream & F, long i_patt) {  // i_patt maju byt
   
   F << "</defs>" << endl;
   // --- end of definitions ---
-  F << "<g transform=\"scale(1,-1)\" fill=\"#000000\" stroke=\"#000000\" stroke-linecap=\"round\" stroke-linejoin=\"round\" stroke-miterlimit=\"10\" fill-rule=\"evenodd\" clip-rule=\"evenodd\" clip-path=\"url(#clip_viewBox_" << i_patt << ")\">" << endl;
-  MP.print_svg(F);
+  F << "<g transform=\"scale(1,-1)\" fill=\"#000000\" stroke=\"#000000\" stroke-linecap=\"round\" stroke-linejoin=\"round\" stroke-miterlimit=\"10\" fill-rule=\"evenodd\" clip-rule=\"evenodd\" clip-path=\"url(#clip_viewBox_" << unique_prefix << ")\">" << endl;
+  MP.print_svg(F,unique_prefix);
   F << "</g>" << endl;
   F << "</svg>" << endl;
 }
@@ -502,11 +512,12 @@ string process_pdf_string2(string s, string font) {
 
 void parse_eps(string fname, string cname, double dx, double dy, 
                double & c1, double & c2, double & c3, double & c4, 
-               converted_data & data) {
+               converted_data & data, double R, double G, double B) {
   string tok, buffer;
   string font, patt;
+  string pattcolor = "0 0 0";
   bool comment = true, concat = false, 
-       already_transp = false, transp_used = false;
+       already_transp = false, transp_used = false, before_group_transp = false;
   double llx = 0, lly = 0, urx = 0, ury = 0, HS = 0.0, VS = 0.0;
   deque<string> thbuffer;
   set<string> FORM_FONTS, FORM_PATTERNS;
@@ -519,7 +530,7 @@ void parse_eps(string fname, string cname, double dx, double dy,
   data.clear();
 
   ifstream F(fname.c_str());
-  if(!F) therror(("Can't open file for reading"));
+  if(!F) therror((IOerr(fname)));
   while(F >> tok) {
     if (comment) {                      // File header
       if (tok == "%%BoundingBox:") {
@@ -542,7 +553,7 @@ void parse_eps(string fname, string cname, double dx, double dy,
                            // for F and G scraps
           data.MP.add(MP_gsave);
           ifstream G(cname.c_str());
-          if(!G) therror(("Can't open file"));
+          if(!G) therror((IOerr(cname)));
           mp_path.clear();
           while(G >> buffer) {
             if (buffer == "m") {
@@ -715,10 +726,14 @@ void parse_eps(string fname, string cname, double dx, double dy,
         if (!inpath) data.MP.add(MP_gsave);
         else gsaveinpath = true;
         thbuffer.clear();
+        if (already_transp) before_group_transp = true;
+        else before_group_transp = false;
       }
       else if (tok == "grestore") {
         if (!inpath) data.MP.add(MP_grestore);
         thbuffer.clear();
+        if (before_group_transp) already_transp = true;
+        else already_transp = false;
       }
       else if (tok == "translate") {
         mp_trans.set(MP_translate,thbuffer[0],thbuffer[1],llx,lly);
@@ -789,10 +804,17 @@ void parse_eps(string fname, string cname, double dx, double dy,
         text.yy = fntmatr.transf[3];
         text.x = fntmatr.transf[4];
         text.y = fntmatr.transf[5];
+	text.r = R;
+	text.g = G;
+	text.b = B;
         concat = false;
         data.MP.add(text);
         thbuffer.clear();
       }
+      else if (tok == "THsetpatterncolor") {
+        pattcolor = thbuffer[0] + " " + thbuffer[1] + " " + thbuffer[2];
+        thbuffer.clear();
+      }
       else {
         thbuffer.push_back(tok);
       }
@@ -812,12 +834,12 @@ void convert_scraps_new() {
   
   for(list<scraprecord>::iterator I = SCRAPLIST.begin(); 
                                   I != SCRAPLIST.end(); I++) {
-    if (I->F != "") parse_eps(I->F, I->C, I->S1, I->S2, I->F1, I->F2, I->F3, I->F4, I->Fc);
+    if (I->F != "") parse_eps(I->F, I->C, I->S1, I->S2, I->F1, I->F2, I->F3, I->F4, I->Fc, I->r, I->g, I->b);
     if (I->G != "") parse_eps(I->G, I->C, I->S1, I->S2, I->G1, I->G2, I->G3, I->G4, I->Gc);
-    if (I->B != "") parse_eps(I->B, "", I->S1, I->S2, I->B1, I->B2, I->G3, I->B4, I->Bc);
+    if (I->B != "") parse_eps(I->B, "", I->S1, I->S2, I->B1, I->B2, I->B3, I->B4, I->Bc);
     if (I->I != "") parse_eps(I->I, "", I->S1, I->S2, I->I1, I->I2, I->I3, I->I4, I->Ic);
-    if (I->E != "") parse_eps(I->E, "", I->S1, I->S2, I->E1, I->E2, I->E3, I->E4, I->Ec);
-    if (I->X != "") parse_eps(I->X, "", I->S1, I->S2, I->X1, I->X2, I->X3, I->X4, I->Xc);
+    if (I->E != "") parse_eps(I->E, "", I->S1, I->S2, I->E1, I->E2, I->E3, I->E4, I->Ec, I->r, I->g, I->b);
+    if (I->X != "") parse_eps(I->X, "", I->S1, I->S2, I->X1, I->X2, I->X3, I->X4, I->Xc, I->r, I->g, I->b);
   }
 
   for(list<legendrecord>::iterator I = LEGENDLIST.begin(); 
@@ -882,9 +904,14 @@ void convert_scraps_new() {
     xstep = strtok(NULL,delim);
     ystep = strtok(NULL,delim);
     matr = strtok(NULL,delim);
-    if (ALL_PATTERNS.count(num) > 0) {
+//    if (ALL_PATTERNS.count(num) > 0) {  // changed to patt.used flag
+                                          // because thsymbolset.cxx 
+                                          // calls eps_parse after
+                                          // this function is called
+                                          // and patterns referenced
+                                          // there would be missing in this list
       pattern patt;
-      
+      patt.used = (ALL_PATTERNS.count(num) > 0);
       patt.name = num;
 
       matr.replace(matr.find("["),1,"");
@@ -902,7 +929,7 @@ void convert_scraps_new() {
 
       parse_eps(pfile , "", 0,0, patt.llx1,patt.lly1,patt.urx1,patt.ury1,patt.data);
       PATTERNLIST.push_back(patt);
-    }
+//    }  // patt.used
   }
   P.close();
  
