@@ -41,6 +41,7 @@ enum {
   TT_IMPORT_FORMAT = 2001,
   TT_IMPORT_FILTER = 2002,
   TT_IMPORT_SURVEYS = 2003,
+  TT_IMPORT_CALIB = 2004,
 };
 
 
@@ -49,6 +50,7 @@ enum {
  */
  
 static const thstok thtt_import_opt[] = {
+  {"calibrate", TT_IMPORT_CALIB},
   {"filter", TT_IMPORT_FILTER},
   {"fmt", TT_IMPORT_FORMAT},
   {"format", TT_IMPORT_FORMAT},
@@ -110,8 +112,9 @@ class thimport : public thdataobject {
 
   // insert here real properties
   int format, surveys;  
-  char * fname, * filter;
+  const char * fname, * filter;
   thobjectsrc mysrc;
+  double calib_x, calib_y, calib_z;
 
   /**
    * Standard constructor.
@@ -138,7 +141,7 @@ class thimport : public thdataobject {
    * Return class name.
    */
    
-  virtual char * get_class_name() {return "thimport";};
+  virtual const char * get_class_name() {return "thimport";};
   
   
   /**
@@ -159,21 +162,21 @@ class thimport : public thdataobject {
    * Return command name.
    */
    
-  virtual char * get_cmd_name();
+  virtual const char * get_cmd_name();
   
   
   /**
    * Return command end option.
    */
    
-  virtual char * get_cmd_end();
+  virtual const char * get_cmd_end();
   
   
   /**
    * Return option description.
    */
    
-  virtual thcmd_option_desc get_cmd_option_desc(char * opts);
+  virtual thcmd_option_desc get_cmd_option_desc(const char * opts);
   
   
   /**
@@ -213,8 +216,10 @@ class thimport : public thdataobject {
   void import_file();
 
   void import_file_img();
+
+  void parse_calib(char * spec, int enc);
   
-  const char * station_name(const char * sn, const char separator, class thsst * sst);
+  const char * station_name(const char * sn, const char separator, struct thsst * sst);
 
 };
 
