@@ -39,6 +39,7 @@
 #include "thparse.h"
 #include <fstream>
 
+
 /**
  * Input file processing class.
  *
@@ -51,6 +52,7 @@ class thinput {
   public:
 
   bool cmd_sensitivity,  ///< Command sensitivity ID.
+    input_sensitivity,  /// < Whether dive into subfiles.
     scan_search_path,  ///< Whether to scan also search path for input files.
     pifo, ///< Print if open.
     * pifoid, ///< Identifier.
@@ -78,7 +80,7 @@ class thinput {
     std::ifstream sh;   ///< file stream.
     thbuffer name,  ///< Input file name buffer.
       path;  ///< Input file path buffer.
-    unsigned int lnumber;  /// Position at the file.
+    unsigned long lnumber;  /// Position at the file.
     int encoding;  /// Current file encoding.
     ifile * prev_ptr,  /// Pointer to the upper file.
       * next_ptr;  /// Pointer to the lower file.
@@ -131,6 +133,9 @@ struct stat
     * last_ptr;  ///< Pointer to the last file.
 
 
+  bool is_first_file();
+
+
   /**
    * Open new file for input.
    */
@@ -221,7 +226,7 @@ struct stat
    * Set main input file name.
    */
    
-  void set_file_name(char * fname);
+  void set_file_name(const char * fname);
   
   
   /**
@@ -235,7 +240,7 @@ struct stat
    * Set search path.
    */
    
-  void set_search_path(char * spath);
+  void set_search_path(const char * spath);
 
   /**
    * Set possible file suffixes.
@@ -243,7 +248,10 @@ struct stat
    * Used, when unable to open input file.
    */
    
-  void set_file_suffix(char * fsx);
+  void set_file_suffix(const char * fsx);
+
+  bool get_input_sensitivity();
+  void set_input_sensitivity(bool s);
   
   
   /**
@@ -298,13 +306,19 @@ struct stat
    */  
    
   char * get_cif_name();
-  
+
+
+  /**
+   * Return current input file path.
+   */  
+   
+  char * get_cif_path();
   
   /**
    * Return current input line number.
    */
    
-  unsigned int get_cif_line_number();
+  unsigned long get_cif_line_number();
   
   
   /**
