@@ -181,6 +181,12 @@ enum {
   TT_LINE_TYPE_CEILING_MEANDER,
   TT_LINE_TYPE_FLOOR_MEANDER,
   TT_LINE_TYPE_MAP_CONNECTION,
+	TT_LINE_TYPE_HANDRAIL,
+	TT_LINE_TYPE_FIXED_LADDER,
+	TT_LINE_TYPE_ROPE_LADDER,
+	TT_LINE_TYPE_VIA_FERRATA,
+	TT_LINE_TYPE_ROPE,
+	TT_LINE_TYPE_STEPS,
 };
 
 /**
@@ -194,10 +200,12 @@ static const thstok thtt_line_types[] = {
   {"ceiling-step", TT_LINE_TYPE_CEILING_STEP},
   {"chimney", TT_LINE_TYPE_CHIMNEY},
   {"contour", TT_LINE_TYPE_CONTOUR},
+  {"fixed-ladder", TT_LINE_TYPE_FIXED_LADDER},
   {"floor-meander", TT_LINE_TYPE_FLOOR_MEANDER},
   {"floor-step", TT_LINE_TYPE_FLOOR_STEP},
   {"flowstone", TT_LINE_TYPE_FLOWSTONE},
   {"gradient", TT_LINE_TYPE_GRADIENT},
+  {"handrail", TT_LINE_TYPE_HANDRAIL},
   {"label", TT_LINE_TYPE_LABEL},
   {"map-connection", TT_LINE_TYPE_MAP_CONNECTION},
   {"moonmilk", TT_LINE_TYPE_MOONMILK},
@@ -206,10 +214,14 @@ static const thstok thtt_line_types[] = {
   {"pitch", TT_LINE_TYPE_PIT},
   {"rock-border", TT_LINE_TYPE_ROCK_BORDER},
   {"rock-edge", TT_LINE_TYPE_ROCK_EDGE},
+  {"rope", TT_LINE_TYPE_ROPE},
+  {"rope-ladder", TT_LINE_TYPE_ROPE_LADDER},
   {"section", TT_LINE_TYPE_SECTION},
   {"slope", TT_LINE_TYPE_SLOPE},
+  {"steps", TT_LINE_TYPE_STEPS},
   {"survey", TT_LINE_TYPE_SURVEY},
   {"u",TT_LINE_TYPE_U},
+  {"via-ferrata",TT_LINE_TYPE_VIA_FERRATA},
   {"wall", TT_LINE_TYPE_WALL},
   {"water-flow", TT_LINE_TYPE_WATER_FLOW},
   {NULL, TT_LINE_TYPE_UNKNOWN},
