@@ -42,8 +42,26 @@ thsurvey::thsurvey()
   this->decdef = false;
   this->decuds = thnan;
   this->num1 = 0;
+  this->level = 0;
   this->person_renames.clear();
+  this->entrance.clear();
   this->data = NULL;
+  this->privatens = true;
+  this->surveyns = NULL;
+}
+
+
+thsurvey * thsurvey::get_nss()
+{
+  if (this->surveyns == NULL) {
+    this->surveyns = this;
+    if (!this->privatens) {
+      while ((!this->surveyns->privatens) && (this->surveyns->fsptr != NULL)) {
+        this->surveyns = this->surveyns->fsptr;
+      }
+    }
+  }
+  return this->surveyns;
 }
 
 
@@ -71,21 +89,21 @@ int thsurvey::get_cmd_nargs()
 }
 
 
-char * thsurvey::get_cmd_end()
+const char * thsurvey::get_cmd_end()
 {
   // insert endcommand if multiline command
   return NULL;
 }
 
 
-char * thsurvey::get_cmd_name()
+const char * thsurvey::get_cmd_name()
 {
   // insert endcommand if multiline command
   return "survey";
 }
 
 
-thcmd_option_desc thsurvey::get_cmd_option_desc(char * opts)
+thcmd_option_desc thsurvey::get_cmd_option_desc(const char * opts)
 {
   int id = thmatch_token(opts, thtt_survey_opt);
   if (id == TT_SURVEY_UNKNOWN)
@@ -99,6 +117,20 @@ thcmd_option_desc thsurvey::get_cmd_option_desc(char * opts)
 }
 
 
+enum {
+  TT_SNS_EXPORT,
+  TT_SNS_PRIVATE,
+  TT_SNS_UNKNOWN,
+};
+ 
+static const thstok thtt_sns[] = {
+  {"off",TT_SNS_EXPORT},
+  {"on",TT_SNS_PRIVATE},
+	{NULL, TT_SNS_UNKNOWN},
+};
+
+
+
 void thsurvey::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long indataline)
 {
   thperson tmpp1, tmpp2;
@@ -107,6 +139,23 @@ void thsurvey::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
     
   switch (cod.id) {
 
+    case TT_SURVEY_NAMESPACE:
+      switch (thmatch_token(*args, thtt_sns)) {
+
+        case TT_SNS_PRIVATE:
+          this->privatens = false;
+          break;
+
+        case TT_SNS_EXPORT:
+          this->privatens = false;
+          break;
+
+        default:
+          ththrow(("invalid -namespace switch -- %s", *args))
+
+      }
+      break;
+
     case TT_SURVEY_DECLINATION:
       this->parse_declination(*args);
       break;
@@ -118,6 +167,10 @@ void thsurvey::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
       tmpp2.parse(this->db, this->db->buff_enc.get_buffer());
       this->person_renames[tmpp1] = tmpp2;
       break;
+
+    case TT_SURVEY_ENTRANCE:
+      thparse_objectname(this->entrance, & this->db->buff_stations, *args);
+      break;
       
     case TT_DATAOBJECT_NAME:
       if (th_is_keyword(*args))
@@ -146,7 +199,7 @@ void thsurvey::self_print_properties(FILE * outf)
   thdataobject::self_print_properties(outf);
   fprintf(outf,"thsurvey:\n");
   fprintf(outf,"\tfull name: \"%s\" (\"%s\")\n", this->full_name,
-    this->reverse_full_name);
+    this->reverse_full_name.get_buffer());
   if (this->decdef) {
     fprintf(outf,"\tdeclination:\n");
     nval = this->declin.get_size();
@@ -166,7 +219,7 @@ int thsurvey::get_context()
   return (THCTX_SURVEY | THCTX_NONE);
 }
 
-char * thsurvey::get_full_name()
+const char * thsurvey::get_full_name()
 {
   return this->full_name;
 }
@@ -267,7 +320,8 @@ void thsurvey::parse_declination(char * str)
 void thsurvey::full_name_reverse()
 {
   size_t fnln = strlen(this->full_name), i1, i2, si; //, ei;
-  char * c1, * c2, *c3;
+  const char * c1, *c3;
+  char * c2;
   c1 = this->full_name;
   si = 0;
   bool has_dot = false;
@@ -275,7 +329,7 @@ void thsurvey::full_name_reverse()
     if ((*c1 == '.') || ((i1 == fnln) && has_dot)) {
       has_dot = true;
       c3 = this->full_name + si;
-      c2 = this->reverse_full_name + fnln - i1;
+      c2 = this->reverse_full_name.get_buffer() + fnln - i1;
       if (i1 < fnln) {
         c2--;
         *c2 = '.';
