@@ -256,6 +256,10 @@ proc xth_me_create_file {} {
 
   global xth
   xth_status_bar_status me ""
+
+  if {$xth(me,fopen) != 0} {
+    return 0
+  }
   
   # create file variables
   set xth(me,unredook) 0
@@ -482,6 +486,11 @@ proc xth_me_read_file {pth changebs} {
   fconfigure $fid -encoding $curenc
   while {![eof $fid]} {
     gets $fid fln
+    if {$flnn == 0} {
+        if {[scan [string index $fln 0] %c] == 65279} {
+            set fln [string range $fln 1 end]
+        }
+    }    
     incr flnn
     if {[regexp {^\s*encoding\s+(\S+)\s*$} $fln encln enc]} {
       if {$encspc} {
