@@ -335,6 +335,7 @@ proc xth_te_show_file {fidx} {
     $xth(te,menu) entryconfigure [mc "Edit"] -state normal
     $xth(te,menu,file) entryconfigure [mc "Save"] -state normal
     $xth(te,menu,file) entryconfigure [mc "Save as"] -state normal
+    $xth(te,menu,file) entryconfigure [mc "Import"] -state normal
     $xth(te,menu,file) entryconfigure [mc "Save all"] -state normal
     $xth(te,menu,file) entryconfigure [mc "Auto save"] -state normal
     $xth(te,menu,file) entryconfigure [mc "Close"] -state normal
@@ -362,6 +363,7 @@ proc xth_te_show_file {fidx} {
     set xth(te,open_file_encoding) $xth(app,fencoding)
     $xth(te,menu,file) entryconfigure [mc "Save"] -state disabled
     $xth(te,menu,file) entryconfigure [mc "Save as"] -state disabled
+    $xth(te,menu,file) entryconfigure [mc "Import"] -state disabled
     $xth(te,menu,file) entryconfigure [mc "Save all"] -state disabled
     $xth(te,menu,file) entryconfigure [mc "Auto save"] -state disabled
     $xth(te,menu,file) entryconfigure [mc "Close"] -state disabled
@@ -547,6 +549,11 @@ proc xth_te_read_file {pth} {
   fconfigure $fid -encoding $curenc
   while {[eof $fid] != 1} {
     gets $fid fln
+    if {$flnn == 0} {
+        if {[scan [string index $fln 0] %c] == 65279} {
+            set fln [string range $fln 1 end]
+        }
+    }
     # replace tabs
     regsub -all {\t} $fln "  " fln
     incr flnn
@@ -600,11 +607,11 @@ proc xth_te_write_file {pth enc txt} {
     return [list $success $nm]
   }
   
-  fconfigure $fid -encoding $curenc -translation {auto lf}
+  fconfigure $fid -encoding $curenc -translation {auto auto}
   if {![string equal $xth(prj,name) svxedit]} {
     puts $fid "encoding  $enc"
   }
-  fconfigure $fid -encoding $enc -translation {auto lf}
+  fconfigure $fid -encoding $enc -translation {auto auto}
   puts -nonewline $fid $txt
   close $fid
   return [list $success $nm]
@@ -713,6 +720,7 @@ proc xth_te_open_file {dialogid fname fline} {
   return 1
 }
 
+
 proc xth_te_before_close_file {cfid btns} {
   global xth
   if {
@@ -908,6 +916,11 @@ $xth(te,menu,file) add command -state disabled -label [mc "Close"] -underline 0
   -font $xth(gui,lfont) \
   -command "xth_te_close_file"
 
+$xth(te,menu,file) add separator
+$xth(te,menu,file) add command -state disabled -label [mc "Import"] -underline 0 \
+  -font $xth(gui,lfont) \
+  -command "xth_te_import_file"
+
 $xth(te,menu,file) add separator
 $xth(te,menu,file) add command -state disabled -label [mc "Next"] \
   -accelerator "$xth(gui,controlk)-n" \
@@ -1111,5 +1124,11 @@ proc xth_te_text_auto_indent {W} {
   
 }
 
+
+
+
+
+
+
 xth_ctrl_minimize te sr
 xth_status_bar_status te [mc "Text editor is not active. To activate it, open existing file or create new one."]
